@@ -183,7 +183,7 @@ static bool gb_raise_window_Close(gMainWindow *sender)
 	if (!_ob) return false;
 	if (GB.Raise((void*)_ob,EVENT_Close,0)) return true;
 
-  if (MAIN_Window && sender == MAIN_Window->widget)
+  if (MAIN_Window && sender == MAIN_Window->ob.widget)
   {
     if (closeAll())
       return true;
@@ -262,7 +262,7 @@ static void cb_deactivate(gMainWindow *sender)
 BEGIN_METHOD(CWINDOW_new, GB_OBJECT parent;)
 
 	GB_CLASS CLASS_container;
-	CWIDGET *parent=NULL;
+	CWIDGET *parent = NULL;
 	int plug = 0;
 
 	if (!MISSING(parent) && VARG(parent))
@@ -281,10 +281,12 @@ BEGIN_METHOD(CWINDOW_new, GB_OBJECT parent;)
 		THIS->embed=true;
 	}
 
-	if (!parent) THIS->widget=new gMainWindow(plug);
-	else         THIS->widget=new gMainWindow((gContainer *)parent->widget);
+	if (!parent) 
+		THIS->ob.widget = new gMainWindow(plug);
+	else
+		THIS->ob.widget = new gMainWindow((gContainer *)parent->widget);
 
-	InitControl(THIS->widget,(CWIDGET*)THIS);
+	InitControl(THIS->ob.widget, (CWIDGET*)THIS);
 	
 	WINDOW->onOpen = gb_raise_window_Open;
 	WINDOW->onShow = gb_raise_window_Show;
@@ -326,12 +328,12 @@ BEGIN_METHOD_VOID(CFORM_main)
 	CWINDOW *form;
 
 	form = (CWINDOW *)GB.AutoCreate(GB.GetClass(NULL), 0);
-	form->widget->show();
+	form->ob.widget->show();
 
 END_METHOD
 
 
-BEGIN_METHOD(CFORM_load, GB_OBJECT parent;GB_BOOLEAN Plug;)
+/*BEGIN_METHOD(CFORM_load, GB_OBJECT parent;GB_BOOLEAN Plug;)
 
 	void *Par=NULL;
 	bool Plg=false;
@@ -343,8 +345,19 @@ BEGIN_METHOD(CFORM_load, GB_OBJECT parent;GB_BOOLEAN Plug;)
 	GB.Push(1, GB_T_OBJECT,Par);
 	GB.AutoCreate(GB.GetClass(NULL),npar);
 
-END_METHOD
+END_METHOD*/
 
+BEGIN_METHOD(CFORM_load, GB_OBJECT parent)
+
+  if (!MISSING(parent))
+  {
+    GB.Push(1, GB_T_OBJECT, VARG(parent));
+    //qDebug("CFORM_load + parent");
+  }
+
+  GB.AutoCreate(GB.GetClass(NULL), MISSING(parent) ? 0 : 1);
+
+END_METHOD
 
 
 BEGIN_METHOD_VOID(CWINDOW_next)
