@@ -210,7 +210,7 @@ void gControl::initAll(gContainer *parent)
 	fg_set = false;
 	have_cursor = false;
 	use_base = false;
-	mous=-1;
+	mous = -1;
 	pr = parent;
 	_name=NULL;
 	visible = false;
@@ -232,9 +232,10 @@ void gControl::initAll(gContainer *parent)
 	onDrop=NULL;
 	onEnterLeave=NULL;
 
-	controls = g_list_append(controls,this);
-	
 	frame = border = widget = 0;
+	hFree = NULL;
+	
+	controls = g_list_append(controls,this);
 }
 
 gControl::gControl()
@@ -617,7 +618,11 @@ gFont* gControl::font()
 
 void gControl::setFont(gFont *ft)
 {
-	gFont::set(&fnt, ft->copy());
+	if (ft)
+		gFont::set(&fnt, ft->copy());
+	else
+		gFont::assign(&fnt);
+		
 	gtk_widget_modify_font(widget, fnt ? fnt->desc() : NULL);
 	resize();
 }
@@ -819,11 +824,15 @@ void gControl::setFocus()
 	
 	if (win->isVisible())
 	{
+		//fprintf(stderr, "setFocus now %s\n", name());
 		//if (isVisible() && bufW > 0 && bufH > 0)
 		gtk_widget_grab_focus(widget);
 	}
 	else
+	{
+		//fprintf(stderr, "setFocus later %s\n", name());
 		win->focus = this;
+	}
 }
 
 bool gControl::hasFocus()
@@ -1053,8 +1062,8 @@ void gControl::connectParent()
   }
   
 	// BM: Widget has been created, so we can set its cursor if application is busy
-	if (gApplication::isBusy())
-    setMouse(-1);		
+	if (gApplication::isBusy() && mustUpdateCursor())
+    setMouse(mouse());		
 }
 
 GList* gControl::controlList()
