@@ -83,6 +83,7 @@ public:
 
 	virtual gFont *font();
 	virtual void setFont(gFont *ft);
+	bool ownFont() { return fnt != 0; }
 	
 	int scrollX();
 	int scrollY();
@@ -182,6 +183,7 @@ public:
 	void initAll(gContainer *pr);
 	void realize(bool make_frame = false);
 	void updateGeometry();
+	bool mustUpdateCursor() { return mouse() != -1 || have_cursor; }
 	
 	bool noInputMethod() { return no_input_method; }
 	
