@@ -124,6 +124,8 @@ void gDraw::initGC()
 	}
 
 	setTransparent(true);
+	setBackground(COLOR_DEFAULT);
+	setForeground(COLOR_DEFAULT);
 }
 
 void gDraw::connect(gControl *wid)
@@ -134,7 +136,7 @@ void gDraw::connect(gControl *wid)
 	clear();
 	reset();
 	
-	ft = new gFont(wid->widget); 
+	ft = wid->font()->copy(); //ft = new gFont(wid->widget); 
 	
 	_width = wid->width();
 	_height = wid->height();
@@ -145,7 +147,7 @@ void gDraw::connect(gControl *wid)
 		_default_bg = gDesktop::bgColor();
 	if (_default_fg == COLOR_DEFAULT)
 		_default_fg = gDesktop::fgColor();
-	
+		
 	stl=gtk_style_copy(wid->widget->style);
 	stl=gtk_style_attach(stl,wid->widget->window);
 
@@ -874,8 +876,9 @@ void gDraw::tiledPicture(gPicture *pic, int x, int y, int w, int h)
 	int sy = -fillY();
 	int sw = pic->width();
 	int sh = pic->height();
-	GdkGCValues val;
 
+	if (!pic || pic->isVoid()) return;
+	
 	if (!sw || !sh )
 		return;
 	
@@ -890,17 +893,45 @@ void gDraw::tiledPicture(gPicture *pic, int x, int y, int w, int h)
 		
 	pixmap = pic->getPixmap();
 	
+	{
+		int yPos, xPos, drawH, drawW, yOff, xOff;
+		yPos = y;
+		yOff = sy;
+		while( yPos < y + h ) 
+		{
+				drawH = sh - yOff;    // Cropping first row
+				if ( yPos + drawH > y + h )        // Cropping last row
+						drawH = y + h - yPos;
+				xPos = x;
+				xOff = sx;
+				while( xPos < x + w ) 
+				{
+						drawW = sw - xOff; // Cropping first column
+						if ( xPos + drawW > x + w )    // Cropping last column
+								drawW = x + w - xPos;
+						picture(pic, xPos, yPos, drawW, drawH, xOff, yOff, drawW, drawH);
+						xPos += drawW;
+						xOff = 0;
+				}
+				yPos += drawH;
+				yOff = 0;
+		}
+	}
+
+	#if 0	
+	//gdk_draw_drawable(dr, gc, pixmap, sx, sy, x, y, sw, sh);
+	
 	gdk_gc_get_values(gc, &val);
 	
-	gdk_gc_set_tile(gc, pixmap);
-	gdk_gc_offset(gc, x-sx, y-sy);
 	gdk_gc_set_fill(gc, GDK_TILED);
+	my_gdk_gc_set_tile(gc, pixmap);
+	gdk_gc_offset(gc, x-sx, y-sy);
 	
 	gdk_draw_rectangle(dr, gc, true, x, y, w, h);
 	
+	//my_gdk_gc_set_tile(gc, NULL);
 	gdk_gc_set_fill(gc, GDK_SOLID);
 	gdk_gc_offset(gc, val.ts_x_origin, val.ts_y_origin);
-	gdk_gc_set_tile(gc, NULL);
 	
 	if (drm)
 	{
@@ -931,6 +962,7 @@ void gDraw::tiledPicture(gPicture *pic, int x, int y, int w, int h)
 		val.foreground.pixel = (foreground() & 0xFF) ? 0 : 1;
 		gdk_gc_set_values(gcm, &val, GDK_GC_FOREGROUND);			
 	}
+	#endif
 }
 
 /****************************************************************************************
@@ -946,7 +978,8 @@ gFont* gDraw::font()
 
 void gDraw::setFont(gFont *f)
 {
-  gFont::set(&ft, f->copy());
+	//if (f != ft)
+	  gFont::set(&ft, f->copy());
 }
 
 
@@ -1057,6 +1090,8 @@ void gDraw::drawLayout(PangoLayout *ly, int x, int y, int w, int h, int align)
 		setForeground(buf);
 	}
 	
+	gt_set_layout_from_font(ly, font());
+	
 	gdk_draw_layout(dr, gc, x + OffX, y + OffY, ly);
 	
 	if (drm && _transparent)
