@@ -139,6 +139,8 @@ gLabel::gLabel(gContainer *parent) : gControl(parent)
 	realize(true);
 
 	g_signal_connect_after(G_OBJECT(widget), "expose-event", G_CALLBACK(cb_expose), (gpointer)this);
+	
+	gt_set_layout_from_font(layout, font());	
 	setAlignment(ALIGN_NORMAL);
 }
 
@@ -297,13 +299,10 @@ void gLabel::setAlignment(int al)
 
 void gLabel::setFont(gFont *ft)
 {
-	PangoFontDescription *desc = pango_context_get_font_description(ft->ct);
-
-	pango_layout_set_font_description(layout,desc);
-	pango_layout_context_changed(layout);
-	
 	gControl::setFont(ft);
 	
+	gt_set_layout_from_font(layout, font());
+	
 	updateSize();
   refresh();
 }
