@@ -1022,8 +1022,8 @@ double gt_from_alignment(int align, bool vertical)
 	{
 		switch(align & 0xF0)
 		{
-			case 1: return 0.0;
-			case 2: return 1.0;
+			case 0x10: return 0.0;
+			case 0x20: return 1.0;
 			default: return 0.5;
 		}
 	}
@@ -1158,13 +1158,13 @@ void gt_pixbuf_render_pixmap_and_mask(GdkPixbuf *pixbuf, GdkPixmap **pixmap_retu
 	{
 		if (gdk_pixbuf_get_has_alpha (pixbuf))
 		{
-		*mask_return = gdk_pixmap_new (gdk_screen_get_root_window (screen),
-						gdk_pixbuf_get_width (pixbuf), gdk_pixbuf_get_height (pixbuf), 1);
-	
-		gdk_pixbuf_render_threshold_alpha (pixbuf, *mask_return,
-								0, 0, 0, 0,
-								gdk_pixbuf_get_width (pixbuf), gdk_pixbuf_get_height (pixbuf),
-								alpha_threshold);
+			*mask_return = gdk_pixmap_new (gdk_screen_get_root_window (screen),
+							gdk_pixbuf_get_width (pixbuf), gdk_pixbuf_get_height (pixbuf), 1);
+		
+			gdk_pixbuf_render_threshold_alpha (pixbuf, *mask_return,
+									0, 0, 0, 0,
+									gdk_pixbuf_get_width (pixbuf), gdk_pixbuf_get_height (pixbuf),
+									alpha_threshold);
 		}
 		else
 			*mask_return = NULL;
@@ -1268,3 +1268,43 @@ void gt_disable_warnings(bool disable)
 		g_log_set_default_handler(old_handler, NULL);
 	fprintf(stderr, "enable warnings\n");
 }
+
+void gt_set_cell_renderer_text_from_font(GtkCellRendererText *cell, gFont *font)
+{
+	g_object_set(G_OBJECT(cell),
+		"font-desc", font->desc(),
+		"underline", font->underline() ? PANGO_UNDERLINE_SINGLE : PANGO_UNDERLINE_NONE,
+		"strikethrough", font->strikeOut(),
+		(void *)NULL);	
+}
+
+void gt_set_layout_from_font(PangoLayout *layout, gFont *font)
+{
+	PangoFontDescription *desc;
+	PangoAttrList *attrs;
+	PangoAttribute *attr;
+	
+	desc = pango_context_get_font_description(font->ct);
+
+	pango_layout_set_font_description(layout, desc);
+	
+	attrs = pango_attr_list_new();
+	
+	if (font->underline())
+	{
+		attr = pango_attr_underline_new(PANGO_UNDERLINE_SINGLE);
+		pango_attr_list_insert(attrs, attr);
+	}
+	
+	if (font->strikeOut())
+	{
+		attr = pango_attr_strikethrough_new(true);
+		pango_attr_list_insert(attrs, attr);
+	}
+	
+	pango_layout_set_attributes(layout, attrs);
+	pango_attr_list_unref(attrs);
+	
+	pango_layout_context_changed(layout);
+	
+}
