@@ -44,17 +44,24 @@ public:
 	static int count() { return g_list_length(trayicons); }
 	static gTrayIcon *get(int index) { return (gTrayIcon *)g_list_nth_data(trayicons, index); }
 	static void exit();	
+	static gPicture *defaultIcon();
 
 //"Private"
 	GtkWidget *plug;
 	gPicture *_icon;
 	char *buftext;
 	bool onHide;
-	GdkPixbuf *getIcon();
-	void updateMask();
+	gPicture *getIcon() { return _icon ? _icon : defaultIcon(); }
+	void refresh();
 	void updateTooltip();
+	void cleanUp();
 	
 	static GList *trayicons;
+	static gPicture *_default_icon;
+
+private:
+
+	GtkStyle *_style;
 };
 
 #endif
