@@ -141,7 +141,7 @@ static uint get_color(GB_DRAW *d, int col, bool bg)
 	return col;
 }
 
-static void begin(GB_DRAW *d)
+static int begin(GB_DRAW *d)
 {
 	void *device = d->device;
 	
@@ -157,7 +157,7 @@ static void begin(GB_DRAW *d)
 		if (pict->pixmap->isNull())
 		{
 			GB.Error("Bad picture");
-			return;
+			return TRUE;
 		}
 
     init_drawing(d, new QPainter(pict->pixmap), pict->pixmap->width(), pict->pixmap->height());
@@ -196,6 +196,7 @@ static void begin(GB_DRAW *d)
 		QPaintDeviceMetrics pdm(printer);
     DRAW_begin(device, new QPainter(printer), pdm.width(), pdm.height(), printer->resolution());
   }*/
+  return FALSE;
 }
 
 static void end(GB_DRAW *d)
@@ -835,3 +836,30 @@ QPainter *DRAW_get_current()
 	return d ? DP(d) : NULL;
 }
 
+
+void DRAW_aligned_pixmap(QPainter *p, const QPixmap &pix, int x, int y, int w, int h, int align)
+{
+	int xp, yp;
+	
+	if (pix.isNull() || pix.width() == 0 || pix.height() == 0)
+		return;
+	
+	xp = x;
+  switch(qApp->horizontalAlignment(align))
+  {
+  	case Qt::AlignRight: xp += w - pix.width(); break;
+  	case Qt::AlignHCenter: xp += (w - pix.width()) / 2; break;
+  	default: break;
+  }
+  
+  yp = y;
+  switch(align & Qt::AlignVertical_Mask)
+  {
+    case Qt::AlignBottom: yp += h - pix.height(); break;
+    case Qt::AlignVCenter: yp += (h - pix.height()) / 2; break;
+    default: break;
+  }
+	
+	p->drawPixmap(xp, yp, pix);
+}
+
