@@ -182,14 +182,20 @@ void GEditor::updateLength()
 
   updateMargin();
 
-  setCellWidth(QMAX(visibleWidth(), margin + charWidth * doc->getMaxLineLength() + 2));
   //qDebug("contentsWidth() = %d  cellWidth() = %d", contentsWidth(), cellWidth());
+	setCellWidth(QMAX(visibleWidth(), margin + charWidth * doc->getMaxLineLength() + 2));
   setCellHeight(fm.lineSpacing());
 
   //if (cache->width() < cellWidth() || cache->height() < cellHeight())
   //  cache->resize(cellWidth(), cellHeight());
   if (cache->width() < visibleWidth() || cache->height() < cellHeight())
-  	cache->resize(visibleWidth(), cellHeight());
+  {
+  	int nw = QMAX(cache->width(), visibleWidth());
+  	int nh = QMAX(cache->height(), cellHeight());
+  	//qDebug("cache->resize(%d, %d)", nw, nh);
+  	cache->resize(nw, nh);
+  }
+  
 	if (pattern.height() < cellHeight())
 		pattern.resize(16, cellHeight());
 
@@ -417,10 +423,10 @@ void GEditor::paintCell(QPainter * painter, int row, int)
 }
 #endif
 
-static void make_blend(QPixmap &pix, QColor start, QColor end) //, bool loop = false)
+static void make_blend(QPixmap &pix, QColor start, QColor end, int height) //, bool loop = false)
 {
 	double r, g, b, dr, dg, db;
-	int n = pix.height() * 3 / 4;
+	int n = height * 3 / 4;
 	int i;
 	QPainter p;
 
@@ -539,7 +545,7 @@ void GEditor::paintCell(QPainter * painter, int row, int)
   {
   	if (getFlag(BlendedProcedureLimits))
   	{
-			make_blend(pattern, styles[GLine::Line].color, color);
+			make_blend(pattern, styles[GLine::Line].color, color, cellHeight());
   		p.drawTiledPixmap(0, 0, cache->width(), cache->height(), pattern);
 		}
 		else
@@ -636,6 +642,8 @@ void GEditor::paintCell(QPainter * painter, int row, int)
 
   p.end();
 
+	//if (cache->width() < visibleWidth())
+	//	qDebug("cache->width() = %d < visibleWidth() = %d", cache->width(), visibleWidth());
   painter->drawPixmap(ur.left(), 0, *cache, 0, 0, cache->width(), cache->height());
 }
 
@@ -841,12 +849,7 @@ void GEditor::cursorLeft(bool shift, bool ctrl)
 {
   if (ctrl && x > 0)
   {
-    int nx;
-
-    nx = doc->wordLeft(y, x, false);
-    if (nx > 0)
-      nx = doc->wordLeft(y, nx, true);
-
+    int nx = doc->wordLeft(y, x);
     cursorGoto(y, nx, shift);
   }
   else
@@ -858,12 +861,7 @@ void GEditor::cursorRight(bool shift, bool ctrl)
 {
   if (ctrl && x < lineLength(y))
   {
-    int nx;
-
-    nx = doc->wordRight(y, x, true);
-    if (nx < lineLength(y))
-      nx = doc->wordRight(y, nx, false);
-
+    int nx = doc->wordRight(y, x);
     cursorGoto(y, nx, shift);
   }
   else
@@ -932,7 +930,7 @@ void GEditor::cursorHome(bool shift, bool ctrl)
 void GEditor::cursorEnd(bool shift, bool ctrl)
 {
   if (ctrl)
-    cursorGoto(numLines(), 0, shift);
+    cursorGoto(numLines() - 1, lineLength(numLines() - 1), shift);
   else
     cursorGoto(y, lineLength(y), shift);
 }
@@ -1132,7 +1130,7 @@ void GEditor::redo()
 void GEditor::selectAll()
 {
   cursorGoto(0, 0, false);
-  cursorGoto(numLines(), 0, true);
+  cursorGoto(numLines() - 1, lineLength(numLines() - 1), true);
 }
 
 void GEditor::keyPressEvent(QKeyEvent *e)
@@ -1392,7 +1390,7 @@ bool GEditor::event(QEvent *e)
 		else
     	ensureVisible(x * charWidth, y * cellHeight() + cellHeight() / 2, margin + 2, cellHeight());
 		center = false;
-    return true;
+    return false;
   }
   /*else if (e->type() == QEvent::KeyPress)
   {
@@ -1429,19 +1427,19 @@ void GEditor::blinkTimerTimeout()
   updateLine(y);
 }
 
-void GEditor::focusInEvent(QFocusEvent *)
+void GEditor::focusInEvent(QFocusEvent *e)
 {
   startBlink();
+  QApplication::postEvent(this, new QEvent(EVENT_ENSURE_VISIBLE));
+  QGridView::focusInEvent(e);
 }
 
-void GEditor::focusOutEvent(QFocusEvent *)
+void GEditor::focusOutEvent(QFocusEvent *e)
 {
-  //if (doc->getHighlightMode() == GDocument::Gambas)
-  //  doc->colorize(y);
   stopBlink();
+  QGridView::focusOutEvent(e);
 }
 
-
 void GEditor::scrollTimerTimeout()
 {
   int ny, nx;
@@ -1470,6 +1468,7 @@ void GEditor::setStyle(int index, GHighlightStyle *style)
 void GEditor::setNumRows(int n)
 {
 	QGridView::setNumRows(n);
+	QGridView::updateScrollBars();
 	if (contentsHeight() < visibleHeight())
     repaintContents(contentsX(), contentsHeight(), visibleWidth(), visibleHeight() - contentsHeight() + contentsX(), true);
 	//if (contentsHeight() < visibleHeight())
@@ -1514,13 +1513,13 @@ void GEditor::updateMargin()
 	
   if (getFlag(ShowLineNumbers))
   {
-    int count = numLines();
+    int cnt = numLines();
 
-    while (count)
+    while (cnt)
     {
       nm += charWidth;
       lnl++;
-      count /= 10;
+      cnt /= 10;
     }
     
     nm += 4;
