@@ -211,7 +211,7 @@ void CWIDGET_init_name(CWIDGET *_object)
 	set_name(THIS, name);
 }
 
-void CWIDGET_new(QWidget *w, void *_object, char *klass /* = NULL */, bool no_filter /* = false */, bool no_init /* = false */)
+void CWIDGET_new(QWidget *w, void *_object, bool no_show, bool no_filter, bool no_init)
 {
   CWidget::add(w, _object, no_filter);
 
@@ -235,6 +235,12 @@ void CWIDGET_new(QWidget *w, void *_object, char *klass /* = NULL */, bool no_fi
 
 	THIS->flag.default_bg = true;
 	THIS->flag.default_fg = true;
+	
+	if (!no_show)
+	{
+		THIS->flag.visible = true;
+		w->show();
+	}
 
 	//WIDGET->setName(THIS->name);
 }
@@ -402,7 +408,7 @@ BEGIN_PROPERTY(CCONTROL_x)
   {
     move_widget(_object, VPROP(GB_INTEGER), COORD(y));
     /*if (WIDGET->isTopLevel())
-      qDebug("X: %d ==> X = %d", PROPERTY(long), WIDGET->x());*/
+      qDebug("X: %d ==> X = %d", PROPERTY(int), WIDGET->x());*/
   }
 
 END_PROPERTY
@@ -455,16 +461,26 @@ BEGIN_PROPERTY(CCONTROL_font)
 
   CFONT *font;
 
+	if (!THIS->font)
+	{
+		THIS->font = CFONT_create(WIDGET->font(), 0, THIS);
+		GB.Ref(THIS->font);
+	}
+
   if (READ_PROPERTY)
-    GB.ReturnObject(CFONT_create(WIDGET->font(), 0, THIS));
+  {
+    GB.ReturnObject(THIS->font);
+  }
   else
   {
     font = (CFONT *)VPROP(GB_OBJECT);
 
-    if (font == 0)
+    if (!font)
       WIDGET->unsetFont();
     else
       WIDGET->setFont(*(font->font));
+    
+    *(((CFONT *)THIS->font)->font) = WIDGET->font();
   }
 
 END_PROPERTY
@@ -489,21 +505,6 @@ BEGIN_PROPERTY(CCONTROL_design)
 END_PROPERTY
 
 
-BEGIN_PROPERTY(CCONTROL_visible)
-
-  if (READ_PROPERTY)
-    GB.ReturnBoolean(!QWIDGET(_object)->isHidden());
-  else
-  {
-    if (VPROP(GB_BOOLEAN))
-      QWIDGET(_object)->show();
-    else
-      QWIDGET(_object)->hide();
-  }
-
-END_PROPERTY
-
-
 BEGIN_PROPERTY(CCONTROL_enabled)
 
   if (READ_PROPERTY)
@@ -590,16 +591,42 @@ BEGIN_METHOD_VOID(CCONTROL_delete)
 END_METHOD
 
 
+static bool is_visible(void *_object)
+{
+	return THIS->flag.visible || !QWIDGET(_object)->isHidden();
+}
+
+
+static void set_visible(void *_object, bool v)
+{
+	THIS->flag.visible = v;
+	if (THIS->flag.visible)
+		QWIDGET(_object)->show();
+	else
+		QWIDGET(_object)->hide();
+}
+
+
+BEGIN_PROPERTY(CCONTROL_visible)
+
+  if (READ_PROPERTY)
+    GB.ReturnBoolean(is_visible(THIS));
+  else
+  	set_visible(THIS, VPROP(GB_BOOLEAN));
+
+END_PROPERTY
+
+
 BEGIN_METHOD_VOID(CCONTROL_show)
 
-  QWIDGET(_object)->show();
+	set_visible(THIS, true);
 
 END_METHOD
 
 
 BEGIN_METHOD_VOID(CCONTROL_hide)
 
-  QWIDGET(_object)->hide();
+	set_visible(THIS, false);
 
 END_METHOD
 
@@ -773,9 +800,13 @@ BEGIN_METHOD_VOID(CCONTROL_set_focus)
   CWINDOW *win = CWidget::getWindow(THIS);
 
   if (QWIDGET(win)->isVisible())
+  {
+  	//qDebug("setFocus now (%s %p)", GB.GetClassName(THIS), THIS);
     WIDGET->setFocus();
+  }
   else if ((CWIDGET *)win != THIS)
   {
+  	//qDebug("setFocus later (%s %p)", GB.GetClassName(THIS), THIS);
     GB.Unref(POINTER(&win->focus));
     win->focus = THIS;
     GB.Ref(THIS);
@@ -887,9 +918,9 @@ BEGIN_PROPERTY(CWIDGET_background)
 
 #if 0
   if (READ_PROPERTY)
-    GB.ReturnInteger((long)(WIDGET->paletteBackgroundColor().rgb() & 0xFFFFFF));
+    GB.ReturnInteger((int)(WIDGET->paletteBackgroundColor().rgb() & 0xFFFFFF));
   else
-    WIDGET->setPaletteBackgroundColor(QColor((QRgb)PROPERTY(long)));
+    WIDGET->setPaletteBackgroundColor(QColor((QRgb)PROPERTY(int)));
 #endif
 
 END_PROPERTY
@@ -906,7 +937,7 @@ BEGIN_PROPERTY(CWIDGET_foreground)
 
   if (READ_PROPERTY)
   {
-    GB.ReturnInteger((long)(wid->paletteForegroundColor().rgb() & 0xFFFFFF));
+    GB.ReturnInteger((int)(wid->paletteForegroundColor().rgb() & 0xFFFFFF));
     return;
   }
   else
@@ -1014,7 +1045,7 @@ END_PROPERTY
 
 BEGIN_PROPERTY(CCONTROL_id)
 
-  GB.ReturnInteger((long)WIDGET->winId());
+  GB.ReturnPointer((void *)WIDGET->winId());
 
 END_PROPERTY
 
@@ -1203,7 +1234,7 @@ END_PROPERTY
 BEGIN_PROPERTY(CWIDGET_scrollbar)
 
   QScrollView *wid = (QScrollView *)QWIDGET(_object);
-  long scroll;
+  int scroll;
 
   if (READ_PROPERTY)
   {
@@ -1524,6 +1555,7 @@ void CWidget::destroy()
 {
   QWidget *w = (QWidget *)sender();
   CWIDGET *ob = CWidget::get(w);
+  QEvent e(EVENT_DESTROY);
 
   if (ob == NULL)
     return;
@@ -1553,13 +1585,14 @@ void CWidget::destroy()
   GB.StoreVariant(NULL, &ob->tag);
   GB.FreeString(&ob->tooltip);
   GB.Unref(POINTER(&ob->cursor));
+  GB.Unref(POINTER(&ob->font));
 
 	CACTION_register(ob, NULL);
   //qDebug(">> CWidget::destroy %p (%p) :%p:%ld #2", ob, ob->widget, ob->ob.klass, ob->ob.ref);
   //if (!CWIDGET_test_flag(ob, WF_NODETACH))
   GB.Detach(ob);
 
-  qApp->sendEvent(w, new QEvent(EVENT_DESTROY));
+  qApp->sendEvent(w, &e);
   //qDebug("<< CWidget::destroy %p (%p)", ob, ob->widget);
 
   GB.Unref(POINTER(&ob));
@@ -1624,9 +1657,9 @@ bool CWidget::eventFilter(QObject *widget, QEvent *event)
   	if (GB.CanRaise(control, EVENT_GotFocus))
   	{
 			GB.Ref(control);
-			GB.Post((void (*)())post_gotfocus_event, (long)control);
+			GB.Post((void (*)())post_gotfocus_event, (intptr_t)control);
 		}
-
+		
 		CWINDOW_activate(control);
     //GB.Raise(control, EVENT_GotFocus, 0);
   }
@@ -1635,7 +1668,7 @@ bool CWidget::eventFilter(QObject *widget, QEvent *event)
   	if (GB.CanRaise(control, EVENT_LostFocus))
   	{
 			GB.Ref(control);
-			GB.Post((void (*)())post_lostfocus_event, (long)control);
+			GB.Post((void (*)())post_lostfocus_event, (intptr_t)control);
 		}
     //GB.Raise(control, EVENT_LostFocus, 0);
   }
@@ -1774,7 +1807,7 @@ bool CWidget::eventFilter(QObject *widget, QEvent *event)
 		if (GB.CanRaise(control, EVENT_DblClick))
 		{
 			GB.Ref(control);
-			GB.Post((void (*)())post_dblclick_event, (long)control);
+			GB.Post((void (*)())post_dblclick_event, (intptr_t)control);
 		}
   }
   else if ((type == QEvent::KeyPress)
