@@ -36,11 +36,14 @@ class SDLcursor
 {
 public:
 	SDLcursor();
-	~SDLcursor() {};
+	SDLcursor(const SDLcursor& cursor);
+	~SDLcursor();
 
 	void Show(void );
 	void SetShape(int );
-	void SetShape(SDLsurface* image, int xhot = -1, int yhot = -1);
+	void SetCursor(SDLsurface* image, int xhot = -1, int yhot = -1);
+
+	int GetShape(void );
 
 private:
 	Cursor hCursor;
