@@ -182,7 +182,7 @@ static void release_one(CARRAY *_object, int i)
       break;
 
     case T_OBJECT:
-      OBJECT_unref(&(((void **)(THIS->data))[i]));
+      OBJECT_UNREF(((void **)(THIS->data))[i], "release_one");
       break;
 
     case T_VARIANT:
@@ -211,7 +211,7 @@ static void release(CARRAY *_object, int start, int end)
 
     case T_OBJECT:
       for (i = start; i < end; i++)
-        OBJECT_unref(&((void **)(THIS->data))[i]);
+        OBJECT_UNREF(((void **)(THIS->data))[i], "release");
       break;
 
     case T_VARIANT:
@@ -241,7 +241,7 @@ static void borrow(CARRAY *_object, int start, int end)
 
     case T_OBJECT:
       for (i = start; i < end; i++)
-        OBJECT_ref(((void **)(THIS->data))[i]);
+        OBJECT_REF(((void **)(THIS->data))[i], "borrow");
       break;
 
     case T_VARIANT:
