@@ -52,30 +52,9 @@
 
 #include "gbx_stream.h"
 
-#if 0
-static long do_nothing(void)
-{
-  return 0;
-}
+int STREAM_eff_read;
 
-PUBLIC STREAM_CLASS STREAM_null =
-{
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing,
-  (void *)do_nothing
-};
-#endif
-
-PUBLIC int STREAM_eff_read;
-
-PUBLIC bool STREAM_in_archive(const char *path)
+bool STREAM_in_archive(const char *path)
 {
 	ARCHIVE *arch;
 
@@ -89,40 +68,53 @@ PUBLIC bool STREAM_in_archive(const char *path)
   return FALSE;
 }
 
-static int STREAM_get_readable(int fd, int *len)
+static int STREAM_get_readable(STREAM *stream, int *len)
 {
+	int fd;
 	int ret;
   off_t off;
   off_t end;
 
+	fd = STREAM_handle(stream);
+	
 //_IOCTL:
 
-	ret = ioctl(fd, FIONREAD, len);
-	if (ret >= 0)
+	if (!stream->common.no_fionread)
 	{
-		//fprintf(stderr, "STREAM_get_readable: ioctl: %d\n", *len);
-		return 0;
+		ret = ioctl(fd, FIONREAD, len);
+		if (ret >= 0)
+			return 0;
+		
+		stream->common.no_fionread = TRUE;
 	}
 
 //_LSEEK:
 
-	off = lseek(fd, 0, SEEK_CUR);
-	if (off < 0) return (-1);
-
-	end = lseek(fd, 0, SEEK_END);
-	if (end < 0) return (-1);
-
-	*len = (int)(end - off);
-
-	off = lseek(fd, off, SEEK_SET);
-	if (off < 0) return (-1);
+	if (!stream->common.no_lseek)
+	{
+		off = lseek(fd, 0, SEEK_CUR);
+		if (off >= 0)
+		{
+			end = lseek(fd, 0, SEEK_END);
+			if (end >= 0)
+			{
+				*len = (int)(end - off);
+	
+				off = lseek(fd, off, SEEK_SET);
+				if (off >= 0)
+					return 0;
+			}
+		}
+		
+		stream->common.no_lseek = TRUE;
+	}
 
 	//fprintf(stderr, "STREAM_get_readable: lseek: %d\n", *len);
-	return 0;
+	return (-1);
 }
 
 
-PUBLIC void STREAM_open(STREAM *stream, const char *path, int mode)
+void STREAM_open(STREAM *stream, const char *path, int mode)
 {
   if (FILE_is_relative(path))
   {
@@ -171,7 +163,7 @@ _OPEN:
 }
 
 
-PUBLIC void STREAM_close(STREAM *stream)
+void STREAM_close(STREAM *stream)
 {
   int fd;
 
@@ -187,7 +179,7 @@ PUBLIC void STREAM_close(STREAM *stream)
 }
 
 
-PUBLIC void STREAM_flush(STREAM *stream)
+void STREAM_flush(STREAM *stream)
 {
   if (!stream->type)
     THROW(E_CLOSED);
@@ -196,7 +188,7 @@ PUBLIC void STREAM_flush(STREAM *stream)
 }
 
 
-PUBLIC void STREAM_read(STREAM *stream, void *addr, int len)
+void STREAM_read(STREAM *stream, void *addr, int len)
 {
   STREAM_eff_read = 0;
 
@@ -218,7 +210,7 @@ PUBLIC void STREAM_read(STREAM *stream, void *addr, int len)
   }
 }
 
-PUBLIC char STREAM_getchar(STREAM *stream)
+char STREAM_getchar(STREAM *stream)
 {
   char c = 0;
   bool ret;
@@ -249,7 +241,7 @@ PUBLIC char STREAM_getchar(STREAM *stream)
 }
 
 
-PUBLIC void STREAM_read_max(STREAM *stream, void *addr, int len)
+void STREAM_read_max(STREAM *stream, void *addr, int len)
 {
   STREAM_eff_read = 0;
 
@@ -272,7 +264,7 @@ PUBLIC void STREAM_read_max(STREAM *stream, void *addr, int len)
 }
 
 
-PUBLIC void STREAM_write(STREAM *stream, void *addr, int len)
+void STREAM_write(STREAM *stream, void *addr, int len)
 {
   if (!stream->type)
     THROW(E_CLOSED);
@@ -289,7 +281,7 @@ PUBLIC void STREAM_write(STREAM *stream, void *addr, int len)
   }
 }
 
-PUBLIC void STREAM_write_eol(STREAM *stream)
+void STREAM_write_eol(STREAM *stream)
 {
   if (!stream->type)
     THROW(E_CLOSED);
@@ -303,9 +295,9 @@ PUBLIC void STREAM_write_eol(STREAM *stream)
 }
 
 
-PUBLIC long long STREAM_tell(STREAM *stream)
+int64_t STREAM_tell(STREAM *stream)
 {
-  long long pos;
+  int64_t pos;
 
   if (!stream->type)
     THROW(E_CLOSED);
@@ -318,7 +310,7 @@ PUBLIC long long STREAM_tell(STREAM *stream)
 }
 
 
-PUBLIC void STREAM_seek(STREAM *stream, long long pos, int whence)
+void STREAM_seek(STREAM *stream, int64_t pos, int whence)
 {
   if (!stream->type)
     THROW(E_CLOSED);
@@ -427,19 +419,19 @@ static void input(STREAM *stream, char **addr, boolean line)
 }
 
 
-PUBLIC void STREAM_line_input(STREAM *stream, char **addr)
+void STREAM_line_input(STREAM *stream, char **addr)
 {
   input(stream, addr, TRUE);
 }
 
 
-PUBLIC void STREAM_input(STREAM *stream, char **addr)
+void STREAM_input(STREAM *stream, char **addr)
 {
   input(stream, addr, FALSE);
 }
 
 
-PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
+void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
 {
   unsigned char data[4];
 
@@ -477,12 +469,12 @@ PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
 
       STREAM_read(stream, &value->_integer.value, sizeof(int));
       if (stream->common.swap)
-        SWAP_long(&value->_integer.value);
+        SWAP_int(&value->_integer.value);
       break;
 
     case T_LONG:
 
-      STREAM_read(stream, &value->_long.value, sizeof(long long));
+      STREAM_read(stream, &value->_long.value, sizeof(int64_t));
       if (stream->common.swap)
         SWAP_double((double *)(void *)&value->_long.value);
       break;
@@ -491,7 +483,7 @@ PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
 
       STREAM_read(stream, data, sizeof(float));
       if (stream->common.swap)
-        SWAP_long((int *)data);
+        SWAP_int((int *)data);
       value->_float.value = (double)*((float *)data);
       break;
 
@@ -508,8 +500,8 @@ PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
       STREAM_read(stream, &value->_date.time, sizeof(int));
       if (stream->common.swap)
       {
-        SWAP_long(&value->_date.date);
-        SWAP_long(&value->_date.time);
+        SWAP_int(&value->_date.date);
+        SWAP_int(&value->_date.time);
       }
       break;
 
@@ -523,8 +515,10 @@ PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
       {
         if (stream->type == &STREAM_memory)
         {
-        	if (CHECK_strlen(stream->memory.addr + stream->memory.pos, &len))
+        	size_t slen;
+        	if (CHECK_strlen(stream->memory.addr + stream->memory.pos, &slen))
             THROW(E_READ);
+          len = (int)slen;
         }
         else
         {
@@ -552,7 +546,7 @@ PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
               *data &= 0x3F;
 
               if (!EXEC_big_endian)
-                SWAP_long((int *)data);
+                SWAP_int((int *)data);
 
               len = *((int *)data);
               break;
@@ -588,7 +582,7 @@ PUBLIC void STREAM_read_type(STREAM *stream, TYPE type, VALUE *value, int len)
 }
 
 
-PUBLIC void STREAM_write_type(STREAM *stream, TYPE type, VALUE *value, int len)
+void STREAM_write_type(STREAM *stream, TYPE type, VALUE *value, int len)
 {
   unsigned char data[8];
   bool write_zero;
@@ -629,23 +623,23 @@ PUBLIC void STREAM_write_type(STREAM *stream, TYPE type, VALUE *value, int len)
 
       *((int *)data) = value->_integer.value;
       if (stream->common.swap)
-        SWAP_long((int *)data);
+        SWAP_int((int *)data);
       STREAM_write(stream, data, sizeof(int));
       break;
 
     case T_LONG:
 
-      *((long long *)data) = value->_long.value;
+      *((int64_t *)data) = value->_long.value;
       if (stream->common.swap)
         SWAP_double((double *)data);
-      STREAM_write(stream, data, sizeof(long long));
+      STREAM_write(stream, data, sizeof(int64_t));
       break;
 
     case T_SINGLE:
 
       *((float *)data) = (float)value->_float.value;
       if (stream->common.swap)
-        SWAP_long((int *)data);
+        SWAP_int((int *)data);
       STREAM_write(stream, data, sizeof(float));
       break;
 
@@ -661,12 +655,12 @@ PUBLIC void STREAM_write_type(STREAM *stream, TYPE type, VALUE *value, int len)
 
       *((int *)data) = value->_date.date;
       if (stream->common.swap)
-        SWAP_long((int *)data);
+        SWAP_int((int *)data);
       STREAM_write(stream, data, sizeof(int));
 
       *((int *)data) = value->_date.time;
       if (stream->common.swap)
-        SWAP_long((int *)data);
+        SWAP_int((int *)data);
       STREAM_write(stream, data, sizeof(int));
 
       break;
@@ -698,7 +692,7 @@ PUBLIC void STREAM_write_type(STREAM *stream, TYPE type, VALUE *value, int len)
           {
             *((int *)data) = len | 0xC0000000;
             if (!EXEC_big_endian)
-              SWAP_long((int *)data);
+              SWAP_int((int *)data);
             STREAM_write(stream, data, 4);
           }
         }
@@ -746,10 +740,10 @@ PUBLIC void STREAM_write_type(STREAM *stream, TYPE type, VALUE *value, int len)
 }
 
 
-PUBLIC void STREAM_load(const char *path, char **buffer, int *rlen)
+void STREAM_load(const char *path, char **buffer, int *rlen)
 {
   STREAM stream;
-  long long len;
+  int64_t len;
 
   STREAM_open(&stream, path, ST_READ);
   STREAM_lof(&stream, &len);
@@ -766,7 +760,7 @@ PUBLIC void STREAM_load(const char *path, char **buffer, int *rlen)
 }
 
 
-PUBLIC bool STREAM_map(const char *path, char **buffer, int *rlen)
+bool STREAM_map(const char *path, char **buffer, int *rlen)
 {
   STREAM stream;
 
@@ -786,7 +780,7 @@ PUBLIC bool STREAM_map(const char *path, char **buffer, int *rlen)
 }
 
 
-PUBLIC int STREAM_handle(STREAM *stream)
+int STREAM_handle(STREAM *stream)
 {
   if (!stream->type)
     THROW(E_CLOSED);
@@ -798,9 +792,9 @@ PUBLIC int STREAM_handle(STREAM *stream)
 }
 
 
-PUBLIC void STREAM_lock(STREAM *stream)
+void STREAM_lock(STREAM *stream)
 {
-  long long pos;
+  int64_t pos;
   int fd;
 
   if (!stream->type)
@@ -836,7 +830,7 @@ __ERROR:
 
 
 
-PUBLIC void STREAM_lof(STREAM *stream, long long *len)
+void STREAM_lof(STREAM *stream, int64_t *len)
 {
   int fd;
   int ilen;
@@ -846,16 +840,18 @@ PUBLIC void STREAM_lof(STREAM *stream, long long *len)
     
 	if (stream->type->lof)
 	{
-  	(*(stream->type->lof))(stream, len);
-  	return;
+  	if (!(*(stream->type->lof))(stream, len))
+  		return;
 	}
 
 	fd = STREAM_handle(stream);
-	if ((fd >= 0) && (STREAM_get_readable(fd, &ilen) == 0))
+	if ((fd >= 0) && (STREAM_get_readable(stream, &ilen) == 0))
 		*len = ilen;
+	else
+		*len = 0;
 }
 
-PUBLIC bool STREAM_eof(STREAM *stream)
+bool STREAM_eof(STREAM *stream)
 {
   int fd;
   int ilen;
@@ -867,14 +863,14 @@ PUBLIC bool STREAM_eof(STREAM *stream)
   	return ((*(stream->type->eof))(stream));
 
 	fd = STREAM_handle(stream);
-  if (fd < 0 || STREAM_get_readable(fd, &ilen))
+  if (fd < 0 || STREAM_get_readable(stream, &ilen))
     return TRUE;
 
   return (ilen == 0);
 }
 
 
-PUBLIC int STREAM_read_direct(int fd, char *buffer, int len)
+int STREAM_read_direct(int fd, char *buffer, int len)
 {
   ssize_t eff_read;
   ssize_t len_read;
@@ -904,7 +900,7 @@ PUBLIC int STREAM_read_direct(int fd, char *buffer, int len)
   return FALSE;
 }
 
-PUBLIC int STREAM_write_direct(int fd, char *buffer, int len)
+int STREAM_write_direct(int fd, char *buffer, int len)
 {
   ssize_t eff_write;
   ssize_t len_write;
