@@ -29,8 +29,8 @@
 
 typedef
   struct {
-    long version;
-    long func[0];
+    int version;
+    void *func[0];
     }
   INTERFACE;
 
@@ -44,7 +44,11 @@ typedef
 #define LIB_GAMBAS       "GB"
 
 #ifdef DONT_USE_LTDL
-#define LIB_PATTERN    "%s/%s." SHARED_LIBRARY_EXT
+ #ifdef OS_OPENBSD
+ #define LIB_PATTERN    "%s/%s." SHARED_LIBRARY_EXT ".0.0"
+ #else
+ #define LIB_PATTERN    "%s/%s." SHARED_LIBRARY_EXT
+ #endif
 #else
 #define LIB_PATTERN    "%s/%s.la"
 #endif
@@ -53,4 +57,7 @@ typedef
 
 #define GAMBAS_LINK_PATH  "/usr/bin/gbx" GAMBAS_VERSION_STRING
 
+#define GAMBAS_LIB_PATH "lib/gambas" GAMBAS_VERSION_STRING
+#define GAMBAS_LIB64_PATH "lib64/gambas" GAMBAS_VERSION_STRING
+
 #endif
