@@ -507,7 +507,7 @@ PUBLIC void TABLE_print(TABLE *table, boolean sort)
   int i;
   SYMBOL *sym;
 
-  fprintf(stderr, "capacity %li\n", ARRAY_count(table->symbol));
+  fprintf(stderr, "capacity %i\n", ARRAY_count(table->symbol));
 
   /*
   for (i = 0; i < ARRAY_count(table->symbol); i++)
